Welcome to ataraxis-automation API documentation page
=====================================================

ataraxis-automation is a Python library that provides scripts that support tox-based development automation pipelines
used by other Sun lab projects.

This library is part of the broader 'Ataraxis' science-automation project, developed in the
`Sun Lab <https://neuroai.github.io/sunlab/>`_ at Cornell University.

This website only contains the API documentation for the classes and methods offered by this library. See the project
GitHub repository for installation instructions and library usage examples:
`ataraxis-automation GitHub repository <https://github.com/Sun-Lab-NBB/ataraxis-automation>`_.

.. _`ataraxis-automation GitHub repository`: https://github.com/Sun-Lab-NBB/ataraxis-automation
.. _`Sun Lab`: https://neuroai.github.io/sunlab/
